package com.jjt.calc.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.jjt.calc.domain.TwinRecordStop;
import org.apache.ibatis.annotations.Options;

/**
 * 停机数据记录Mapper接口
 *
 * @author wukai
 * @date 2025-01-18
 */
public interface TwinRecordStopMapper extends BaseMapper<TwinRecordStop>
{
    /**
     * 查询停机数据记录
     *
     * @param id 停机数据记录主键
     * @return 停机数据记录
     */
    public TwinRecordStop selectTwinRecordStopById(Long id);

    /**
     * 查询停机数据记录列表
     *
     * @param twinRecordStop 停机数据记录
     * @return 停机数据记录集合
     */
    public List<TwinRecordStop> selectTwinRecordStopList(TwinRecordStop twinRecordStop);

    /**
     * 新增停机数据记录
     *
     * @param twinRecordStop 停机数据记录
     * @return 结果
     */
    public int insertTwinRecordStop(TwinRecordStop twinRecordStop);

    /**
     * 修改停机数据记录
     *
     * @param twinRecordStop 停机数据记录
     * @return 结果
     */
    public int updateTwinRecordStop(TwinRecordStop twinRecordStop);

    /**
     * 删除停机数据记录
     *
     * @param id 停机数据记录主键
     * @return 结果
     */
    public int deleteTwinRecordStopById(Long id);

    /**
     * 批量删除停机数据记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTwinRecordStopByIds(Long[] ids);
}
